@@ -1,18 +1,20 @@
 #' @title
-#' Generator for the Insertion mutation operator.
+#' Insertion mutator.
 #'
 #' @description
 #' The Insertion mutation operator selects a position random and inserts it at
 #' a random position.
 #'
-#' @return [\code{ecr_mutator}]
+#' @param ind [\code{integer}]\cr
+#'   Permutation of integers, i.e., vector of integer values.
+#' @return [\code{integer}]
 #' @family mutators
 #' @export
-setupInsertionMutator = function() {
-  mutator = function(ind, task, control) {
-    n.params = length(ind)
+mutInsertion = makeMutator(
+  mutator = function(ind) {
+    n = length(ind)
     # select a random position and insert it at another random location
-    idx = sample(seq(n.params), size = 2L)
+    idx = sample(seq(n), size = 2L)
     # idx[1] is the selected position
     # idx[2] is the destination
     # equality is impossible, since replace = FALSE in sample above
@@ -22,13 +24,5 @@ setupInsertionMutator = function() {
     ind[idx[1]:(idx[2] - offset)] = ind[(idx[1] + offset):idx[2]]
     ind[idx[2]] = tmp
     return(ind)
-  }
-
-  makeMutator(
-    mutator = mutator,
-    name = "Insertion mutator",
-    description = "Selects two positions at random, places the first position to
-    the second and shift the other elements accordingly.",
-    supported = "permutation"
-  )
-}
+  },
+  supported = "permutation")
